[source] ar71xx: add support for YunCore CPE830

LEDE Commits lede-commits at lists.infradead.org
Mon Nov 21 01:58:06 PST 2016


blogic pushed a commit to source.git, branch master:
https://git.lede-project.org/e33dcd1cfe105cb0e1ad09887144e4911eac653f

commit e33dcd1cfe105cb0e1ad09887144e4911eac653f
Author: Piotr Dymacz <pepe2k at gmail.com>
AuthorDate: Sat Oct 8 03:36:35 2016 +0200

    ar71xx: add support for YunCore CPE830
    
    CPE830 is a clone of AP90Q, with different type of antenna (panel)
    and additional 4 LEDs for WiFi signal level indication.
    
    Use the same flash approach as for YunCore AP90Q.
    
    Signed-off-by: Piotr Dymacz <pepe2k at gmail.com>
---
 target/linux/ar71xx/base-files/etc/board.d/01_leds |   2 +
 target/linux/ar71xx/base-files/etc/diag.sh         |   1 +
 target/linux/ar71xx/base-files/lib/ar71xx.sh       |   3 +
 .../ar71xx/base-files/lib/upgrade/platform.sh      |   1 +
 target/linux/ar71xx/config-4.4                     |   1 +
 .../ar71xx/files/arch/mips/ath79/Kconfig.openwrt   |   9 ++
 target/linux/ar71xx/files/arch/mips/ath79/Makefile |   1 +
 .../ar71xx/files/arch/mips/ath79/mach-ap90q.c      | 130 ++++++++++++++++-----
 .../linux/ar71xx/files/arch/mips/ath79/machtypes.h |   1 +
 target/linux/ar71xx/image/generic.mk               |   8 ++
 10 files changed, 131 insertions(+), 26 deletions(-)

diff --git a/target/linux/ar71xx/base-files/etc/board.d/01_leds b/target/linux/ar71xx/base-files/etc/board.d/01_leds
index 2cf72d6..383695c 100755
--- a/target/linux/ar71xx/base-files/etc/board.d/01_leds
+++ b/target/linux/ar71xx/base-files/etc/board.d/01_leds
@@ -58,6 +58,7 @@ ap147-010)
 	ucidef_set_led_wlan "wlan2g" "WLAN 2.4 GHz" "ap147:green:wlan-2g" "phy0tpt"
 	;;
 ap90q|\
+cpe830|\
 cpe870|\
 dr531)
 	ucidef_set_led_netdev "lan" "LAN" "$board:green:lan" "eth0"
@@ -67,6 +68,7 @@ dr531)
 	ap90q)
 		ucidef_set_led_wlan "wlan" "WLAN" "$board:green:wlan" "phy0tpt"
 		;;
+	cpe830|\
 	cpe870)
 		ucidef_set_led_wlan "wlan" "WLAN" "$board:green:wlan" "phy0tpt"
 		ucidef_set_rssimon "wlan0" "200000" "1"
diff --git a/target/linux/ar71xx/base-files/etc/diag.sh b/target/linux/ar71xx/base-files/etc/diag.sh
index e619749..b18a096 100644
--- a/target/linux/ar71xx/base-files/etc/diag.sh
+++ b/target/linux/ar71xx/base-files/etc/diag.sh
@@ -48,6 +48,7 @@ get_status_led() {
 		status_led="$board:green:power"
 		;;
 	ap90q|\
+	cpe830|\
 	cpe870|\
 	gl-inet)
 		status_led="$board:green:lan"
diff --git a/target/linux/ar71xx/base-files/lib/ar71xx.sh b/target/linux/ar71xx/base-files/lib/ar71xx.sh
index 0d4c1e0..37af9d4 100755
--- a/target/linux/ar71xx/base-files/lib/ar71xx.sh
+++ b/target/linux/ar71xx/base-files/lib/ar71xx.sh
@@ -526,6 +526,9 @@ ar71xx_board_detect() {
 		name="cpe510"
 		tplink_pharos_board_detect
 		;;
+	*CPE830)
+		name="cpe830"
+		;;
 	*CPE870)
 		name="cpe870"
 		;;
diff --git a/target/linux/ar71xx/base-files/lib/upgrade/platform.sh b/target/linux/ar71xx/base-files/lib/upgrade/platform.sh
index 66f6308..887a0f0 100755
--- a/target/linux/ar71xx/base-files/lib/upgrade/platform.sh
+++ b/target/linux/ar71xx/base-files/lib/upgrade/platform.sh
@@ -188,6 +188,7 @@ platform_check_image() {
 	cf-e380ac-v2|\
 	cf-e520n|\
 	cf-e530n|\
+	cpe830|\
 	cpe870|\
 	dgl-5500-a1|\
 	dhp-1565-a1|\
diff --git a/target/linux/ar71xx/config-4.4 b/target/linux/ar71xx/config-4.4
index 794e7f8..c6a757a 100644
--- a/target/linux/ar71xx/config-4.4
+++ b/target/linux/ar71xx/config-4.4
@@ -69,6 +69,7 @@ CONFIG_ATH79_MACH_CF_E380AC_V2=y
 CONFIG_ATH79_MACH_CF_E520N=y
 CONFIG_ATH79_MACH_CF_E530N=y
 CONFIG_ATH79_MACH_CPE510=y
+CONFIG_ATH79_MACH_CPE830=y
 CONFIG_ATH79_MACH_CPE870=y
 CONFIG_ATH79_MACH_CR3000=y
 CONFIG_ATH79_MACH_CR5000=y
diff --git a/target/linux/ar71xx/files/arch/mips/ath79/Kconfig.openwrt b/target/linux/ar71xx/files/arch/mips/ath79/Kconfig.openwrt
index 6daa093..001edbe 100644
--- a/target/linux/ar71xx/files/arch/mips/ath79/Kconfig.openwrt
+++ b/target/linux/ar71xx/files/arch/mips/ath79/Kconfig.openwrt
@@ -1211,6 +1211,15 @@ config ATH79_MACH_CPE510
 	select ATH79_DEV_M25P80
 	select ATH79_DEV_WMAC
 
+config ATH79_MACH_CPE830
+	bool "YunCore CPE830 support"
+	select SOC_QCA953X
+	select ATH79_DEV_ETH
+	select ATH79_DEV_GPIO_BUTTONS
+	select ATH79_DEV_LEDS_GPIO
+	select ATH79_DEV_M25P80
+	select ATH79_DEV_WMAC
+
 config ATH79_MACH_CPE870
 	bool "YunCore CPE870 support"
 	select SOC_AR934X
diff --git a/target/linux/ar71xx/files/arch/mips/ath79/Makefile b/target/linux/ar71xx/files/arch/mips/ath79/Makefile
index b718d6b..ac2dbbb 100644
--- a/target/linux/ar71xx/files/arch/mips/ath79/Makefile
+++ b/target/linux/ar71xx/files/arch/mips/ath79/Makefile
@@ -75,6 +75,7 @@ obj-$(CONFIG_ATH79_MACH_CF_E380AC_V2)		+= mach-cf-e316n-v2.o
 obj-$(CONFIG_ATH79_MACH_CF_E520N)		+= mach-cf-e316n-v2.o
 obj-$(CONFIG_ATH79_MACH_CF_E530N)		+= mach-cf-e316n-v2.o
 obj-$(CONFIG_ATH79_MACH_CPE510)			+= mach-cpe510.o
+obj-$(CONFIG_ATH79_MACH_CPE830)			+= mach-ap90q.o
 obj-$(CONFIG_ATH79_MACH_CPE870)			+= mach-cpe870.o
 obj-$(CONFIG_ATH79_MACH_CR3000)			+= mach-cr3000.o
 obj-$(CONFIG_ATH79_MACH_CR5000)			+= mach-cr5000.o
diff --git a/target/linux/ar71xx/files/arch/mips/ath79/machtypes.h b/target/linux/ar71xx/files/arch/mips/ath79/machtypes.h
index 50ecff4..9a8da22 100644
--- a/target/linux/ar71xx/files/arch/mips/ath79/machtypes.h
+++ b/target/linux/ar71xx/files/arch/mips/ath79/machtypes.h
@@ -61,6 +61,7 @@ enum ath79_mach_type {
 	ATH79_MACH_CF_E530N,			/* COMFAST CF-E530N */
 	ATH79_MACH_CPE210,			/* TP-LINK CPE210 */
 	ATH79_MACH_CPE510,			/* TP-LINK CPE510 */
+	ATH79_MACH_CPE830,			/* YunCore CPE830 */
 	ATH79_MACH_CPE870,			/* YunCore CPE870 */
 	ATH79_MACH_CR3000,			/* PowerCloud CR3000 */
 	ATH79_MACH_CR5000,			/* PowerCloud CR5000 */
diff --git a/target/linux/ar71xx/image/generic.mk b/target/linux/ar71xx/image/generic.mk
index 0b8a216..331509a 100644
--- a/target/linux/ar71xx/image/generic.mk
+++ b/target/linux/ar71xx/image/generic.mk
@@ -80,6 +80,14 @@ define Device/cf-e530n
 endef
 TARGET_DEVICES += cf-e530n
 
+define Device/cpe830
+  $(Device/ap90q)
+  DEVICE_TITLE := YunCore CPE830
+  DEVICE_PACKAGES := rssileds
+  BOARDNAME = CPE830
+endef
+TARGET_DEVICES += cpe830
+
 define Device/cpe870
   DEVICE_TITLE := YunCore CPE870
   DEVICE_PACKAGES := rssileds



More information about the lede-commits mailing list
diff --git a/target/linux/ar71xx/files/arch/mips/ath79/mach-ap90q.c b/target/linux/ar71xx/files/arch/mips/ath79/mach-ap90q.c
index 35e5781..2e9d34d 100644
--- a/target/linux/ar71xx/files/arch/mips/ath79/mach-ap90q.c
+++ b/target/linux/ar71xx/files/arch/mips/ath79/mach-ap90q.c
@@ -1,5 +1,7 @@
 /*
  * YunCore AP90Q board support
  *
  * Copyright (C) 2016 Piotr Dymacz <pepe2k at gmail.com>
  *
@@ -23,6 +25,7 @@
 #include "dev-wmac.h"
 #include "machtypes.h"
 
+/* AP90Q */
 #define AP90Q_GPIO_LED_WAN	4
 #define AP90Q_GPIO_LED_WLAN	12
 #define AP90Q_GPIO_LED_LAN	16
@@ -61,40 +64,62 @@ static struct gpio_keys_button ap90q_gpio_keys[] __initdata = {
 	},
 };
 
-static void __init ap90q_gpio_setup(void)
-{
-	/* For LED on GPIO4 */
-	ath79_gpio_function_disable(AR934X_GPIO_FUNC_CLK_OBS4_EN);
-
-	ath79_gpio_direction_select(AP90Q_GPIO_LED_LAN, true);
-	ath79_gpio_direction_select(AP90Q_GPIO_LED_WAN, true);
-	ath79_gpio_direction_select(AP90Q_GPIO_LED_WLAN, true);
-
-	/* Mute LEDs on boot */
-	gpio_set_value(AP90Q_GPIO_LED_LAN, 1);
-	gpio_set_value(AP90Q_GPIO_LED_WAN, 1);
-
-	ath79_gpio_output_select(AP90Q_GPIO_LED_LAN, 0);
-	ath79_gpio_output_select(AP90Q_GPIO_LED_WAN, 0);
-	ath79_gpio_output_select(AP90Q_GPIO_LED_WLAN, 0);
+/* CPE830 */
+#define CPE830_GPIO_LED_LINK4	0
+#define CPE830_GPIO_LED_LINK1	1
+#define CPE830_GPIO_LED_LINK2	2
+#define CPE830_GPIO_LED_LINK3	3
+#define CPE830_GPIO_LED_WAN	4
+#define CPE830_GPIO_LED_WLAN	12
+#define CPE830_GPIO_LED_LAN	16
 
-	ath79_register_leds_gpio(-1, ARRAY_SIZE(ap90q_leds_gpio),
-				 ap90q_leds_gpio);
+#define CPE830_GPIO_BTN_RESET	17
 
-	ath79_register_gpio_keys_polled(-1, AP90Q_KEYS_POLL_INTERVAL,
-					ARRAY_SIZE(ap90q_gpio_keys),
-					ap90q_gpio_keys);
-}
+static struct gpio_led cpe830_leds_gpio[] __initdata = {
+	{
+		.name		= "cpe830:green:lan",
+		.gpio		= CPE830_GPIO_LED_LAN,
+		.active_low	= 1,
+	},
+	{
+		.name		= "cpe830:green:wan",
+		.gpio		= CPE830_GPIO_LED_WAN,
+		.active_low	= 1,
+	},
+	{
+		.name		= "cpe830:green:wlan",
+		.gpio		= CPE830_GPIO_LED_WLAN,
+		.active_low	= 1,
+	},
+	{
+		.name		= "cpe830:green:link1",
+		.gpio		= CPE830_GPIO_LED_LINK1,
+		.active_low	= 1,
+	},
+	{
+		.name		= "cpe830:green:link2",
+		.gpio		= CPE830_GPIO_LED_LINK2,
+		.active_low	= 1,
+	},
+	{
+		.name		= "cpe830:green:link3",
+		.gpio		= CPE830_GPIO_LED_LINK3,
+		.active_low	= 1,
+	},
+	{
+		.name		= "cpe830:green:link4",
+		.gpio		= CPE830_GPIO_LED_LINK4,
+		.active_low	= 1,
+	},
+};
 
-static void __init ap90q_setup(void)
+static void __init ap90q_cpe830_common_setup(void)
 {
 	u8 *art = (u8 *) KSEG1ADDR(0x1fff1000);
 	u8 *mac = (u8 *) KSEG1ADDR(0x1fff0000);
 
 	ath79_register_m25p80(NULL);
 
-	ap90q_gpio_setup();
-
 	ath79_setup_ar933x_phy4_switch(false, false);
 
 	ath79_register_mdio(0, 0x0);
@@ -118,6 +143,59 @@ static void __init ap90q_setup(void)
 	ath79_register_eth(0);
 
 	ath79_register_wmac(art, NULL);
+
+	/* For LED on GPIO4 */
+	ath79_gpio_function_disable(AR934X_GPIO_FUNC_CLK_OBS4_EN);
+
+	ath79_gpio_direction_select(AP90Q_GPIO_LED_LAN, true);
+	ath79_gpio_direction_select(AP90Q_GPIO_LED_WAN, true);
+	ath79_gpio_direction_select(AP90Q_GPIO_LED_WLAN, true);
+
+	/* Mute LEDs on boot */
+	gpio_set_value(AP90Q_GPIO_LED_LAN, 1);
+	gpio_set_value(AP90Q_GPIO_LED_WAN, 1);
+
+	ath79_gpio_output_select(AP90Q_GPIO_LED_LAN, 0);
+	ath79_gpio_output_select(AP90Q_GPIO_LED_WAN, 0);
+	ath79_gpio_output_select(AP90Q_GPIO_LED_WLAN, 0);
+
+	ath79_register_gpio_keys_polled(-1, AP90Q_KEYS_POLL_INTERVAL,
+					ARRAY_SIZE(ap90q_gpio_keys),
+					ap90q_gpio_keys);
+}
+
+static void __init ap90q_setup(void)
+{
+	ap90q_cpe830_common_setup();
+
+	ath79_register_leds_gpio(-1, ARRAY_SIZE(ap90q_leds_gpio),
+				 ap90q_leds_gpio);
 }
 
 MIPS_MACHINE(ATH79_MACH_AP90Q, "AP90Q", "YunCore AP90Q", ap90q_setup);
+
+static void __init cpe830_setup(void)
+{
+	ap90q_cpe830_common_setup();
+
+	ath79_gpio_direction_select(CPE830_GPIO_LED_LINK1, true);
+	ath79_gpio_direction_select(CPE830_GPIO_LED_LINK2, true);
+	ath79_gpio_direction_select(CPE830_GPIO_LED_LINK3, true);
+	ath79_gpio_direction_select(CPE830_GPIO_LED_LINK4, true);
+
+	/* Mute LEDs on boot */
+	gpio_set_value(CPE830_GPIO_LED_LINK1, 1);
+	gpio_set_value(CPE830_GPIO_LED_LINK2, 1);
+	gpio_set_value(CPE830_GPIO_LED_LINK3, 1);
+	gpio_set_value(CPE830_GPIO_LED_LINK4, 1);
+
+	ath79_gpio_output_select(CPE830_GPIO_LED_LINK1, 0);
+	ath79_gpio_output_select(CPE830_GPIO_LED_LINK2, 0);
+	ath79_gpio_output_select(CPE830_GPIO_LED_LINK3, 0);
+	ath79_gpio_output_select(CPE830_GPIO_LED_LINK4, 0);
+
+	ath79_register_leds_gpio(-1, ARRAY_SIZE(cpe830_leds_gpio),
+				 cpe830_leds_gpio);
+}
+
+MIPS_MACHINE(ATH79_MACH_CPE830, "CPE830", "YunCore CPE830", cpe830_setup);
@@ -1,5 +1,7 @@
 /*
- * YunCore AP90Q board support
+ * Support for YunCore boards:
+ * - AP90Q
+ * - CPE830
  *
  * Copyright (C) 2016 Piotr Dymacz <pepe2k at gmail.com>